#
# spec file for package kea
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define asiodns_sover 35
%define asiolink_sover 56
%define cc_sover 54
%define cfgclient_sover 51
%define cryptolink_sover 38
%define d2srv_sover 30
%define database_sover 48
%define dhcppp_sover 74
%define dhcp_ddns_sover 41
%define dhcpsrv_sover 90
%define dnspp_sover 42
%define eval_sover 52
%define exceptions_sover 23
%define hooks_sover 78
%define http_sover 56
%define log_sover 48
%define mysql_sover 53
%define pgsql_sover 53
%define process_sover 57
%define stats_sover 29
%define tcp_sover 5
%define util_io_sover 0
%define util_sover 68
%if 0%{?suse_version} >= 1500
%bcond_without regen_files
%else
%bcond_with    regen_files
%endif
Name:           kea
Version:        2.4.1
Release:        2.2
Summary:        Dynamic Host Configuration Protocol daemon
License:        MPL-2.0
Group:          Productivity/Networking/Boot/Servers
URL:            https://kea.isc.org/
#Git-Clone:     https://gitlab.isc.org/isc-projects/kea
#Github is out of date / abandoned(?)
Source:         https://ftp.isc.org/isc/kea/%version/kea-%version.tar.gz
Source2:        https://ftp.isc.org/isc/kea/%version/kea-%version.tar.gz.asc
# https://www.isc.org/pgpkey/
Source3:        kea.keyring
BuildRequires:  autoconf >= 2.59
BuildRequires:  automake
BuildRequires:  bison >= 3.3
BuildRequires:  freeradius-server-devel
BuildRequires:  gcc-c++
BuildRequires:  libmysqlclient-devel
BuildRequires:  libtool >= 2
BuildRequires:  log4cplus-devel
BuildRequires:  pkg-config >= 0.23
BuildRequires:  postgresql-server-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-Sphinx
BuildRequires:  sysuser-tools
BuildRequires:  xz
BuildRequires:  pkgconfig(libcrypto)
%sysusers_requires
Suggests:       %name-hooks = %version
%if 0%{with regen_files}
BuildRequires:  flex
%endif
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  systemd-rpm-macros

%description
Kea is a new DHCPv4/DHCPv6 server being developed by ISC in C++, a
continuation of the DHCP server in the (ended) BIND10 project. The
objective of this project is to provide a very high-performance,
extensible DHCP server engine for use by enterprises and service
providers, either as-is or with extensions and modifications.

%package        doc
Summary:        Documentation for Kea
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
This package contains the documentation for Kea.

%package hooks
Summary:        Standard Kea DHCP hooks/plugins
Group:          System/Libraries

%description hooks
A standard set of external libraries used to provide additional
functionality for Kea DHCP server

%package -n libkea-asiodns%asiodns_sover
Summary:        Kea DHCP server asiolink abstraction layer library
Group:          System/Libraries

%description -n libkea-asiodns%asiodns_sover
The asiodns library provides an abstraction layer between BIND10/Kea
modules and the asiolink library.

%package -n libkea-asiolink%asiolink_sover
Summary:        Kea DHCP server socket I/O abstraction layer library
Group:          System/Libraries

%description -n libkea-asiolink%asiolink_sover
The asiolink library provides an abstraction layer between BIND10/Kea
modules and the socket I/O subsystem Kea is using (currently,
boost::asio).

%package -n libkea-cc%cc_sover
Summary:        Kea DHCP server command channel library
Group:          System/Libraries

%description -n libkea-cc%cc_sover
libkea-cc is used for the control channel protocol between keactrl
and the server.

%package -n libkea-cfgclient%cfgclient_sover
Summary:        Kea DHCP server configuration client library
Group:          System/Libraries

%description -n libkea-cfgclient%cfgclient_sover
The Kea DHCP server can be managed at runtime via the Control
Channel. The CC allows an external entity (e.g. a tool run by a
sysadmin or a script) to issue commands to the server which can
influence its behavior or retreive information from it. Examples
envisioned are: reconfiguration, statistics retrieval and
manipulation, and shutdown.

Communication over the Control Channel is conducted using JSON
structures.

%package -n libkea-cryptolink%cryptolink_sover
Summary:        Kea DHCP server crypto abstraction layer library
Group:          System/Libraries

%description -n libkea-cryptolink%cryptolink_sover
The Kea cryptolink library is an abstraction layer for crypto
library backends (such as Botan, OpenSSL).

%package -n libkea-d2srv%d2srv_sover
Summary:        Kea DHCP-DDNS service library
Group:          System/Libraries

%description -n libkea-d2srv%d2srv_sover
This library provides DHCP-DDNS specific event loop and business logic.

%package -n libkea-database%database_sover
Summary:        Kea database abstraction library
Group:          System/Libraries

%description -n libkea-database%database_sover
Kea's database abstraction library.

%package -n libkea-dhcp++%dhcppp_sover
Summary:        Kea DHCP library
Group:          System/Libraries

%description -n libkea-dhcp++%dhcppp_sover
libdhcp++ is an all-purpose DHCP-manipulation library, written in
C++. It offers packet parsing and assembly, DHCPv4 and DHCPv6 options
parsing and assembly, interface detection, and socket operations It
can be used by server, client, relay, performance tools and other
DHCP-related tools. For a server-specific library, see
libkea-dhcpsrv.

%package -n libkea-dhcp_ddns%dhcp_ddns_sover
Summary:        Kea DHCP Dynamic DNS library
Group:          System/Libraries

%description -n libkea-dhcp_ddns%dhcp_ddns_sover
This is a library of classes for sending and receiving requests used
by ISC's DHCP-DDNS (aka D2) service to carry out DHCP-driven DNS
updates.

%package -n libkea-dhcpsrv%dhcpsrv_sover
Summary:        Kea DHCP server component library
Group:          System/Libraries

%description -n libkea-dhcpsrv%dhcpsrv_sover
This library contains code used for the DHCPv4 and DHCPv6 servers'
operations, including the "Lease Manager" that manages information
about leases and the "Configuration Manager" that stores the servers'
configuration etc.

%package -n libkea-dns++%dnspp_sover
Summary:        Kea DHCP server component library
Group:          System/Libraries

%description -n libkea-dns++%dnspp_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n libkea-eval%eval_sover
Summary:        Kea DHCP expression evaluation library
Group:          System/Libraries

%description -n libkea-eval%eval_sover
The core of the libeval library is a parser that is able to parse an
expression (e.g. option[123].text == 'APC'). This is currently used
for client classification.

%package -n libkea-exceptions%exceptions_sover
Summary:        Kea DHCP server component library
Group:          System/Libraries

%description -n libkea-exceptions%exceptions_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n libkea-hooks%hooks_sover
Summary:        Kea DHCP server hook library
Group:          System/Libraries

%description -n libkea-hooks%hooks_sover
The hooks framework is a Kea system that simplifies the way that
users can write code to modify the behavior of Kea. Instead of
altering the Kea source code, they write functions that are compiled
and linked into one or more dynamic shared objects. The library is
specified in the Kea configuration and, at runtime, Kea dynamically
loads the library into its address space. At various points in the
processing, the component "calls out" to functions in the library,
passing to them the data is it currently working on. They can examine
and modify the data as required.

%package -n libkea-http%http_sover
Summary:        Kea DHCP http communication library
Group:          System/Libraries

%description -n libkea-http%http_sover
This library is used by Control Agent to establish HTTP connections,
receive messages and send responses over HTTP. This library uses
boost ASIO for creating TCP connections and asynchronously receive
and send the data over the sockets.

%package -n libkea-log%log_sover
Summary:        Kea DHCP logging system library
Group:          System/Libraries

%description -n libkea-log%log_sover
This library contains the Kea logging system, which is based on the
log4J logging system common in Java development, and includes the
following ideas: a set of severity levels; a hierarchy of logging
sources; separation of message use from message text.

%package -n libkea-mysql%mysql_sover
Summary:        Kea MySQL database library
Group:          System/Libraries

%description -n libkea-mysql%mysql_sover
Kea's database library for MySQL.

%package -n libkea-pgsql%pgsql_sover
Summary:        Kea PostgreSQL database library
Group:          System/Libraries

%description -n libkea-pgsql%pgsql_sover
Kea's database library for PostgreSQL.

%package -n libkea-process%process_sover
Summary:        Kea DHCP process abstraction library
Group:          System/Libraries

%description -n libkea-process%process_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n libkea-stats%stats_sover
Summary:        Kea DHCP Statistics Manager library
Group:          System/Libraries

%description -n libkea-stats%stats_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n libkea-tcp%tcp_sover
Summary:        Kea TCP library
Group:          System/Libraries

%description -n libkea-tcp%tcp_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n libkea-util-io%util_io_sover
Summary:        Kea I/O utility function library
Group:          System/Libraries

%description -n libkea-util-io%util_io_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n libkea-util%util_sover
Summary:        Kea utility function library
Group:          System/Libraries

%description -n libkea-util%util_sover
One of the many libraries the Kea DHCP server is composed of.

%package -n python3-kea
Summary:        Python interface to Kea DHCP server
Group:          Development/Libraries/Python

%description -n python3-kea
Python3 interface to ISC Kea DHCP server.

%package devel
Summary:        Development files for the Kea DHCP server
Group:          Development/Libraries/C and C++
Requires:       libkea-asiodns%asiodns_sover = %version
Requires:       libkea-asiolink%asiolink_sover = %version
Requires:       libkea-cc%cc_sover = %version
Requires:       libkea-cfgclient%cfgclient_sover = %version
Requires:       libkea-cryptolink%cryptolink_sover = %version
Requires:       libkea-d2srv%d2srv_sover = %version
Requires:       libkea-database%database_sover = %version
Requires:       libkea-dhcp++%dhcppp_sover = %version
Requires:       libkea-dhcp_ddns%dhcp_ddns_sover = %version
Requires:       libkea-dhcpsrv%dhcpsrv_sover = %version
Requires:       libkea-dns++%dnspp_sover = %version
Requires:       libkea-eval%eval_sover = %version
Requires:       libkea-exceptions%exceptions_sover = %version
Requires:       libkea-hooks%hooks_sover = %version
Requires:       libkea-http%http_sover = %version
Requires:       libkea-log%log_sover = %version
Requires:       libkea-mysql%mysql_sover = %version
Requires:       libkea-pgsql%pgsql_sover = %version
Requires:       libkea-process%process_sover = %version
Requires:       libkea-stats%stats_sover = %version
Requires:       libkea-tcp%tcp_sover = %version
Requires:       libkea-util%util_sover = %version
Requires:       libkea-util-io%util_io_sover = %version
# Bundy DHCP and Kea share the same origin, so conflict
Conflicts:      otheproviders(pkgconfig(dns++))

%description devel
Development files for the Kea DHCP server

%prep
%autosetup -p1 -n kea-%version

%build
export FREERADIUS_INCLUDE="%_includedir/freeradius"
export FREERADIUS_LIB=""
export FREERADIUS_DICTIONARY=""
autoreconf -fi
%configure \
	--disable-rpath --disable-static \
%if 0%{with regen_files}
	--enable-generate-docs --enable-generate-parser \
%endif
	--enable-logger-checks \
	--with-dhcp-mysql --with-dhcp-pgsql \
	--enable-perfdhcp --enable-shell
make %{?_smp_mflags}

%install
b=%buildroot
%make_install
find %buildroot -type f -name "*.la" -delete -print
mkdir -p "$b/%_unitdir" "$b/%_tmpfilesdir" "$b/%_sysusersdir"
cat <<-EOF >"$b/%_unitdir/kea.service"
	[Unit]
	Description=ISC Kea DHCP server
	Before=multi-user.target
	After=remote-fs.target network.target nss-lookup.target time-sync.target ldap.service ndsd.service
	[Service]
	Type=forking
	Environment=KEA_PIDFILE_DIR=%_rundir/%name
        RuntimeDirectory=kea
	ExecStart=%_sbindir/keactrl start
	ExecReload=%_sbindir/keactrl reload
	ExecStop=%_sbindir/keactrl stop
	[Install]
	WantedBy=multi-user.target
	Alias=dhcp-server.service
EOF
cat <<-EOF >"$b/%_tmpfilesdir/kea.conf"
	d /run/kea 0775 keadhcp keadhcp -
EOF
echo 'u keadhcp - "Kea DHCP server" /var/lib/kea' >system-user-keadhcp.conf
cp -a system-user-keadhcp.conf "$b/%_sysusersdir/"
%sysusers_generate_pre system-user-keadhcp.conf random system-user-keadhcp.conf

perl -i -pe 's{%_localstatedir/log/kea-}{%_localstatedir/log/kea/}' \
	"$b/%_sysconfdir/kea"/*.conf

mkdir -p "$b%_localstatedir/log/kea"
ln -s "%_sbindir/service" "%buildroot/%_sbindir/rc%name"

# Remove unnecessary files
find "%buildroot/%_libdir" -name "*.so.*" -type l -delete
rm -Rf "%buildroot/%python3_sitelib/kea/__pycache__"

%pre -f random.pre
systemd-tmpfiles --create kea.conf || :
%service_add_pre kea.service

%post
%service_add_post kea.service

%preun
%service_del_preun kea.service

%postun
%service_del_postun kea.service

%post   -n libkea-asiodns%asiodns_sover -p /sbin/ldconfig
%postun -n libkea-asiodns%asiodns_sover -p /sbin/ldconfig
%post   -n libkea-asiolink%asiolink_sover -p /sbin/ldconfig
%postun -n libkea-asiolink%asiolink_sover -p /sbin/ldconfig
%post   -n libkea-cc%cc_sover -p /sbin/ldconfig
%postun -n libkea-cc%cc_sover -p /sbin/ldconfig
%post   -n libkea-cfgclient%cfgclient_sover -p /sbin/ldconfig
%postun -n libkea-cfgclient%cfgclient_sover -p /sbin/ldconfig
%post   -n libkea-cryptolink%cryptolink_sover -p /sbin/ldconfig
%postun -n libkea-cryptolink%cryptolink_sover -p /sbin/ldconfig
%post   -n libkea-d2srv%d2srv_sover -p /sbin/ldconfig
%postun -n libkea-d2srv%d2srv_sover -p /sbin/ldconfig
%post   -n libkea-database%database_sover -p /sbin/ldconfig
%postun -n libkea-database%database_sover -p /sbin/ldconfig
%post   -n libkea-dhcp++%dhcppp_sover -p /sbin/ldconfig
%postun -n libkea-dhcp++%dhcppp_sover -p /sbin/ldconfig
%post   -n libkea-dhcp_ddns%dhcp_ddns_sover -p /sbin/ldconfig
%postun -n libkea-dhcp_ddns%dhcp_ddns_sover -p /sbin/ldconfig
%post   -n libkea-dhcpsrv%dhcpsrv_sover -p /sbin/ldconfig
%postun -n libkea-dhcpsrv%dhcpsrv_sover -p /sbin/ldconfig
%post   -n libkea-dns++%dnspp_sover -p /sbin/ldconfig
%postun -n libkea-dns++%dnspp_sover -p /sbin/ldconfig
%post   -n libkea-eval%eval_sover -p /sbin/ldconfig
%postun -n libkea-eval%eval_sover -p /sbin/ldconfig
%post   -n libkea-exceptions%exceptions_sover -p /sbin/ldconfig
%postun -n libkea-exceptions%exceptions_sover -p /sbin/ldconfig
%post   -n libkea-hooks%hooks_sover -p /sbin/ldconfig
%postun -n libkea-hooks%hooks_sover -p /sbin/ldconfig
%post   -n libkea-http%http_sover -p /sbin/ldconfig
%postun -n libkea-http%http_sover -p /sbin/ldconfig
%post   -n libkea-log%log_sover -p /sbin/ldconfig
%postun -n libkea-log%log_sover -p /sbin/ldconfig
%post   -n libkea-mysql%mysql_sover -p /sbin/ldconfig
%postun -n libkea-mysql%mysql_sover -p /sbin/ldconfig
%post   -n libkea-pgsql%pgsql_sover -p /sbin/ldconfig
%postun -n libkea-pgsql%pgsql_sover -p /sbin/ldconfig
%post   -n libkea-process%process_sover -p /sbin/ldconfig
%postun -n libkea-process%process_sover -p /sbin/ldconfig
%post   -n libkea-stats%stats_sover -p /sbin/ldconfig
%postun -n libkea-stats%stats_sover -p /sbin/ldconfig
%post   -n libkea-tcp%tcp_sover -p /sbin/ldconfig
%postun -n libkea-tcp%tcp_sover -p /sbin/ldconfig
%post   -n libkea-util-io%util_io_sover -p /sbin/ldconfig
%postun -n libkea-util-io%util_io_sover -p /sbin/ldconfig
%post   -n libkea-util%util_sover -p /sbin/ldconfig
%postun -n libkea-util%util_sover -p /sbin/ldconfig

%files
%dir %_sysconfdir/kea
%config(noreplace) %_sysconfdir/kea/*.conf
%_mandir/man8/*.8%{?ext_man}
%_sbindir/rckea
%_sbindir/kea*
%_sbindir/perfdhcp
%_datadir/kea/
%_unitdir/*.service
%dir %_localstatedir/lib/kea
%_tmpfilesdir/
%_sysusersdir/
%attr(0775,keadhcp,keadhcp) %_localstatedir/log/kea/

%files doc
%doc %_datadir/doc/kea/
%exclude %_datadir/doc/kea/html/.buildinfo

%files hooks
%dir %_libdir/kea
%_libdir/kea/hooks/

%files -n libkea-asiodns%asiodns_sover
%_libdir/libkea-asiodns.so.%asiodns_sover.*

%files -n libkea-asiolink%asiolink_sover
%_libdir/libkea-asiolink.so.%asiolink_sover.*

%files -n libkea-cc%cc_sover
%_libdir/libkea-cc.so.%cc_sover.*

%files -n libkea-cfgclient%cfgclient_sover
%_libdir/libkea-cfgclient.so.%cfgclient_sover.*

%files -n libkea-cryptolink%cryptolink_sover
%_libdir/libkea-cryptolink.so.%cryptolink_sover.*

%files -n libkea-d2srv%d2srv_sover
%_libdir/libkea-d2srv.so.%d2srv_sover.*

%files -n libkea-database%database_sover
%_libdir/libkea-database.so.%database_sover.*

%files -n libkea-dhcp++%dhcppp_sover
%_libdir/libkea-dhcp++.so.%dhcppp_sover.*

%files -n libkea-dhcp_ddns%dhcp_ddns_sover
%_libdir/libkea-dhcp_ddns.so.%dhcp_ddns_sover.*

%files -n libkea-dhcpsrv%dhcpsrv_sover
%_libdir/libkea-dhcpsrv.so.%dhcpsrv_sover.*

%files -n libkea-dns++%dnspp_sover
%_libdir/libkea-dns++.so.%dnspp_sover.*

%files -n libkea-eval%eval_sover
%_libdir/libkea-eval.so.%eval_sover.*

%files -n libkea-exceptions%exceptions_sover
%_libdir/libkea-exceptions.so.%exceptions_sover.*

%files -n libkea-hooks%hooks_sover
%_libdir/libkea-hooks.so.%hooks_sover.*

%files -n libkea-http%http_sover
%_libdir/libkea-http.so.%http_sover.*

%files -n libkea-log%log_sover
%_libdir/libkea-log.so.%log_sover.*

%files -n libkea-mysql%mysql_sover
%_libdir/libkea-mysql.so.%mysql_sover.*

%files -n libkea-pgsql%pgsql_sover
%_libdir/libkea-pgsql.so.%pgsql_sover.*

%files -n libkea-process%process_sover
%_libdir/libkea-process.so.%process_sover.*

%files -n libkea-stats%stats_sover
%_libdir/libkea-stats.so.%stats_sover.*

%files -n libkea-tcp%tcp_sover
%_libdir/libkea-tcp.so.%tcp_sover.*

%files -n libkea-util-io%util_io_sover
%_libdir/libkea-util-io.so.%util_io_sover.*

%files -n libkea-util%util_sover
%_libdir/libkea-util.so.%util_sover.*

%files -n python3-kea
%python3_sitelib/kea/

%files devel
%_includedir/kea/
%_libdir/libkea*.so

%changelog
* Sat Feb  3 2024 Jan Engelhardt <jengelh@inai.de>
- Generate "keadhcp" user with sysusers mechanism
* Mon Jan  8 2024 Richard Rahl <rrahl0@proton.me>
- Update to release 2.4.1
  * fix a race condition in FLQ in which kea could crash
  * fix a regression where redetection of interfaces stopped working
* Thu Jul  6 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add RuntimeDirectory to kea.service
- Update to release 2.4.0
  Breaking Changes:
  * Both MySQL and PostgreSQL database schemas were updated to
    accommodate DHCPv6 Bulk Leasequery support.
  * The values accepted by `operation-target` used in
    `reservation-*` commands have been renamed: primary ->
    memory, alternate -> database.
  * Kea DHCPv4 server can now handle multiple `vivco-suboptions`
    options with different enterprise IDs and multiple vendor
    options.
  * The Discovery of Network-designated Resolvers (DNR) options
    have been implemented for both DHCPv4 and DHCPv6. The options
    allow configuration.
  * Template classes mechanism, similar to spawning classes in
    ISC DHCP, has been implemented.
  * Kea now keeps leases for a period of time after they are
    released.
  * An address reserved in a global reservation must now lie
    within the range of the subnet or shared-network selected by
    Kea.
  * It is now possible to add an "empty" host reservation without
    any attribute.
  * kea-dhcp4 now supports the `offer-lifetime` parameter to
    allow the temporary allocation of leases during DHCPOFFER.
  * Added support for Secure Zero Touch Provisioning options, per
    RFC8572.
  * The kea-dhcp6 `prefix-len` and `pd-pools` list now checks the
    prefix lengths correctly.
  * The preferred lifetime is now calculated as 0.625 *
    `valid-lifetime` unless explicitly specified.
  * The link selection suboption is now optional.
  * See /usr/share/doc/kea/ChangeLog in the kea-doc package for
    details.
* Wed Dec 14 2022 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Separate documentation into kea-doc package
- Remove following packages from BuildRequires
  * docbook-xsl-stylesheets
  * elinks
  * libxslt-tools
* Thu Aug 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.0
  * Kea now features full native support for TLS in HA
  * PostgreSQL configuration backend
  * A new hook is dedicated to RBAC.
  * A new hook limits the rate and number of leases.
  * A new DDNS Tuning library adds custom behaviors related to
    Dynamic DNS updates on a per-client basis.
  * The subnet_cmds hook has been expanded with several new
    commands: `subnet4-delta-add`, `subnet4-delta-del`,
    `subnet6-delta-add`, and `subnet6-delta-del`.
* Mon Oct  4 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.0
  * In Kea 2.0, the HA component has undergone a substantial
    architectural change. When HA+MT is enabled, the DHCPv4 and
    DHCPv6 daemons are now able to open HTTP sockets on their own
    and connect directly to each other, bypassing the Control Agent
    (CA). This eliminates the bottlenecks of sequential UNIX socket
    connection and the need to translate between HTTP and UNIX
    socket connections.
  * A new parameter on-fail gives the operator more control over
    what to do on database connection loss.
  * The length of the "parking lot queue" is now configurable; a
    default value of 256 is used.
  * A new statistic, `packet-queue-size`, has been added that
    reports packet-queue utilization.
* Thu Jun  3 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.9.8
  * Kea now recognizes requests sent from vendors that include
    their information in DHCPv6 Vendor Class option (code 16).
  * Fixed the server ignoring the Subnet Selection option
    supplied by a client if its query contained a Relay Agent
    Information (RAI) option without a Link Selection option.
* Sat May 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.9.7
  * The Control Agent now supports TLS/HTTPS.
  * kea-shell supports TLS/HTTPS.
  * kea-admin now accepts the -P, --port parameter
  * kea-dhcp4 now supports specifying valid-lifetime in
    client classes.
* Mon Apr  5 2021 Samu Voutilainen <smar@smar.fi>
- Own directory /var/lib/kea, as that is used as default for
  memfile lease store.
* Tue Nov 10 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.9.1
  * New parameters: ddns-use-conflict-resolution,
    ip-reservations-unique, ddns-update-on-renew,
    cache-threshold, cache-max-age.
  * Support for new IPv6-only-preferred option for DHCPv4.
  * Added support of basic HTTP authentication in HTTP library,
    control agent.
* Sat Sep  5 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.0
  * User-defined option definitions were not committed, which was
    fixed.
  * kea-dhcp4 now rejects inbound client messages that have
    neither a hardware address nor a client identifier.
  * Rather than within the 'dhcp-ddns' section, DDNS behavioral
    parameters may now be specified at global, shared-network,
    and subnet scopes.
  * Added support of BOOTP leases with infinite valid lifetime.
  * Added the -N command line switch that enables experimental
    multi-threading support.
* Wed Apr 22 2020 Steve Kowalik <steven.kowalik@suse.com>
- Switch to Python 3 Sphinx due to Python 2 removal.
* Mon Sep  9 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * Corrected multiple occurrences of out of bounds vector reads.
  * Corrected a bug in the Kea MySQL Configuration Backend which
    caused the Kea DHCPv6 server to incorrectly require the
    server tag to be provided with the remote-subnet6-option-set
    command.
  * Corrected a bug in the Kea MySQL Configuration Backend which
    prevented the DHCP servers from discovering and fetching the
    changes applied with the new commands.
  * Prevent the DHCP servers from asserting when malformed
    hostname or FQDN options are received.
* Tue Aug 27 2019 Adam Majer <adam.majer@suse.de>
- Update keyring file
- Temporarily hardcode version in upstream URLs
* Wed Aug 21 2019 Adam Majer <adam.majer@suse.de>
- Update to version 1.6.0~beta2
  * Default file locations for lease file, server-duid, log files and lock
    files have changed. Files previously stored in `/var/kea` are now stored
    in `/var/run/kea`. Server hooks previously installed in `/usr/lib/hooks`
    are now installed in `/usr/lib/kea/hooks`. The log files are now stored
    in `/var/log/kea`.
  * The kea-admin commands (lease-init, lease-version, lease-upgrade) were
    renamed to better reflect the fact that the database can store much more
    than just leases. They're now called db-init, db-version, db-upgrade.
  * The Logging entry in the configuration file has moved to specific
    daemon sections. This require a simple configuration file modification.
    You need to move Logging entry from its global scope into the Dhcp4,
    Dhcp6, DhcpDdns, Control-agent or Netconf scope.
  Please see 1.6 migration wiki
  https://gitlab.isc.org/isc-projects/kea/wikis/migrating-to-kea-1.6
  For release notes, see
  https://ftp.isc.org/isc/kea/1.6.0-beta2/Kea160beta2ReleaseNotes.txt
- Fix building of perfdhcp
- Enable building of kea-shell
- Update sonames of all affected libraries and ship only libraries,
  allowing `ldconfig` to actually make the symlinks
- Rework spec file to abstract soversions
* Fri Dec 28 2018 mardnh@gmx.de
- Update to version 1.5.0
  * Support for YANG/NETCONF, the ability to store major
    configuration elements in a YANG model and manipulate it
    using NETCONF.
  * Support for global host reservations (previously each host
    reservation had to be associated with a specific subnet)
  * Class commands – a new hook that allows dynamic changes
    to be made to client classes without restarting.
  * Performance and resiliency improvements to the High
    Availability hook.
  * A new congestion control feature to mitigate the effects of
    heavy DHCP traffic conditions.
  * Improvements to the High Availability feature, including paged
    updates between HA pairs to alleviate timeouts.
- Run spec-cleaner
* Tue Jun 19 2018 jengelh@inai.de
- Remove unnecessary ldconfig call for kea-hooks: files are
  outside standard search dirs.
- Drop --disable-dependency-tracking, this is already part of
  %%configure.
* Mon Jun 18 2018 adam.majer@suse.de
- update to new upstream release 1.4.0
- fix licence - Mozilla Public License v2.0
- package default hook libraries
- regenerate parser and documentation
- add ISC keyring (2017 & 2018)
* Fri Jun 30 2017 jengelh@inai.de
- Stop on errors from useradd/groupadd
* Fri Jun 30 2017 obs@botter.cc
- compile in support for MySQL and PostgresQL
- add symlink to rckea
- add environment variable for PID_FILE_DIR to service file
* Sat May 27 2017 obs@botter.cc
- Update to new upstream release 1.2.0
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 1.0.0
* Mon Dec  8 2014 jengelh@inai.de
- Initial package (version 0.9.g20262) for build.opensuse.org
